==> aria2-1.10.3.tar.xz: aria2-1.10.3/src/BtAllowedFastMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "BtAllowedFastMessage.h"
#include "DlAbortEx.h"
#include "Peer.h"
#include "StringFormat.h"

namespace aria2 {

const std::string BtAllowedFastMessage::NAME("allowed fast");

BtAllowedFastMessage::BtAllowedFastMessage(size_t index):
  IndexBtMessage(ID, NAME, index) {}

SharedHandle<BtAllowedFastMessage> BtAllowedFastMessage::create
(const unsigned char* data, size_t dataLength)
{
  return IndexBtMessage::create<BtAllowedFastMessage>(data, dataLength);
}

void BtAllowedFastMessage::doReceivedAction() {
  if(!getPeer()->isFastExtensionEnabled()) {
    throw DL_ABORT_EX
      (StringFormat("%s received while fast extension is disabled",
                    toString().c_str()).str());
  }
  if(isMetadataGetMode()) {
    return;
  }
  getPeer()->addPeerAllowedIndex(getIndex());
}

void BtAllowedFastMessage::onSendComplete() {
  getPeer()->addAmAllowedIndex(getIndex());
}

} // namespace aria2

==> aria2-1.18.0.tar.xz: aria2-1.18.0/src/BtAllowedFastMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "BtAllowedFastMessage.h"
#include "DlAbortEx.h"
#include "Peer.h"
#include "fmt.h"
#include "SocketBuffer.h"

namespace aria2 {

const char BtAllowedFastMessage::NAME[] = "allowed fast";

BtAllowedFastMessage::BtAllowedFastMessage(size_t index):
  IndexBtMessage(ID, NAME, index) {}

std::unique_ptr<BtAllowedFastMessage> BtAllowedFastMessage::create
(const unsigned char* data, size_t dataLength)
{
  return IndexBtMessage::create<BtAllowedFastMessage>(data, dataLength);
}

void BtAllowedFastMessage::doReceivedAction() {
  if(!getPeer()->isFastExtensionEnabled()) {
    throw DL_ABORT_EX
      (fmt("%s received while fast extension is disabled",
           toString().c_str()));
  }
  if(isMetadataGetMode()) {
    return;
  }
  getPeer()->addPeerAllowedIndex(getIndex());
}

namespace {
struct ThisProgressUpdate : public ProgressUpdate {
  ThisProgressUpdate(const std::shared_ptr<Peer>& peer, size_t index)
    : peer(peer), index(index) {}
  virtual void update(size_t length, bool complete) CXX11_OVERRIDE
  {
    if(complete) {
      peer->addAmAllowedIndex(index);
    }
  }
  std::shared_ptr<Peer> peer;
  size_t index;
};
} // namespace

std::unique_ptr<ProgressUpdate> BtAllowedFastMessage::getProgressUpdate()
{
  return make_unique<ThisProgressUpdate>(getPeer(), getIndex());
}

} // namespace aria2
